==> BSgenome.Scerevisiae.UCSC.sacCer3_1.3.19.tar.gz: BSgenome.Scerevisiae.UCSC.sacCer3/man/package.Rd <==
\name{BSgenome.Scerevisiae.UCSC.sacCer3}
\docType{package}

\alias{BSgenome.Scerevisiae.UCSC.sacCer3-package}
\alias{BSgenome.Scerevisiae.UCSC.sacCer3}
\alias{Scerevisiae}

\title{Saccharomyces cerevisiae (Yeast) full genome (UCSC version sacCer3)}

\description{
  Saccharomyces cerevisiae (Yeast) full genome as provided by UCSC (sacCer3, April 2011) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
http://hgdownload.cse.ucsc.edu/goldenPath/sacCer3/bigZips/chromFa.tar.gz

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{The Bioconductor Dev Team}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
BSgenome.Scerevisiae.UCSC.sacCer3
genome <- BSgenome.Scerevisiae.UCSC.sacCer3
seqlengths(genome)
genome$chrI  # same as genome[["chrI"]]

if ("AGAPS" \%in\% masknames(genome)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(genome)) {
    cat("Checking sequence", seqname, "... ")
    seq <- genome[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}

==> BSgenome.Scerevisiae.UCSC.sacCer3_1.3.1000.tar.gz: BSgenome.Scerevisiae.UCSC.sacCer3/man/package.Rd <==
\name{BSgenome.Scerevisiae.UCSC.sacCer3}
\docType{package}

\alias{BSgenome.Scerevisiae.UCSC.sacCer3-package}
\alias{BSgenome.Scerevisiae.UCSC.sacCer3}
\alias{Scerevisiae}

\title{Saccharomyces cerevisiae (Yeast) full genome (UCSC version sacCer3)}

\description{
  Saccharomyces cerevisiae (Yeast) full genome as provided by UCSC (sacCer3, April 2011) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
http://hgdownload.cse.ucsc.edu/goldenPath/sacCer3/bigZips/chromFa.tar.gz

  }

  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the \pkg{BSgenome}
  software package for how to make a BSgenome data package.
}

\author{The Bioconductor Dev Team}

\seealso{
  \itemize{
    \item \link[BSgenome]{BSgenome} objects and the
          \code{\link[BSgenome]{available.genomes}} function
          in the \pkg{BSgenome} software package.
    \item \link[Biostrings]{DNAString} objects in the \pkg{Biostrings}
          package.
    \item The BSgenomeForge vignette (\code{vignette("BSgenomeForge")})
          in the \pkg{BSgenome} software package for how to make a BSgenome
          data package.
  }
}

\examples{
BSgenome.Scerevisiae.UCSC.sacCer3
genome <- BSgenome.Scerevisiae.UCSC.sacCer3
seqlengths(genome)
genome$chrI  # same as genome[["chrI"]]

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
